@@ -39,14 +39,13 @@ Q_OBJECT
 
 public:
     kpToolPolyline (kpToolEnvironment *environ, QObject *parent);
-    virtual ~kpToolPolyline ();
 
 private:
     virtual QString haventBegunShapeUserMessage () const;
 
 public:
     // (used by kpToolLine)
-    static void DrawShape (kpImage *image,
+    static void drawShape(kpImage *image,
         const QPolygon &points,
         const kpColor &fcolor, int penWidth,
         const kpColor &bcolor,
