@@ -50,20 +50,9 @@
 #include "widgets/toolbars/options/kpToolWidgetOpaqueOrTransparent.h"
 #include "views/kpView.h"
 #include "views/manager/kpViewManager.h"
-
 #include "kpLogCategories.h"
-#include <klocale.h>
 
-// LOREFACTOR: Remove unneeded #include
-#include <qapplication.h>
-#include <qbitmap.h>
-#include <qcursor.h>
-#include <qevent.h>
-#include <qmenu.h>
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qpolygon.h>
-#include <qtimer.h>
+#include <KLocalizedString>
 
 
 // protected
